# Installation
`pip install data-catapult`
`pip install bamboo-lib`

## Required if using locking

### Installing Sherlock on OS X

```brew install libmemcached```
```pip install pylibmc --install-option="--with-libmemcached=/usr/local/Cellar/libmemcached/1.0.18_2"```
```pip install sherlock```
